Contains the logic for applying a parsed patch to file content.
This module includes the backtracking patcher implementation.
Modules
- backtracking_
patcher - Implements backtracking-based patch application for a sequence of chunks.
- state
- Defines the state used during the backtracking patch application process.
- whitespace_
mode - Defines the
WhitespaceModeenum for controlling patch matching sensitivity.